// ===========================================================
// CA2POV Tutorial : example scene. 
// --
// Jaime Vives Piqueres, 2008-2009.
// ===========================================================
// For the introduction and general details, go to:
// http://www.ignorancia.org/en/index.php?page=Chief_Architect
// ===========================================================
// Render instructions:
// + 1st pass: set use_radiosity=2 and use_area=0 
// + 2nd pass: set use_radiosity=1,use_area=1
// + just remember to render the 1st pass again anytime you change the location of anything
// +w800 +h800
// ===========================================================
#version 3.6;
//#version unofficial MegaPov 1.21; // change the above directive for this one if you are using MegaPOV

// ===========================================================
// radiosity control: see tips on the tutorial
// ===========================================================
#declare use_radiosity= 2; // 1=load, 2=save, 0=off
#declare rad_quality=   2; // 1-10 (1=basic, 2=decent, 3=good, >3=very good, but much patience required)
#declare rad_bounces=   3; // >0 (more of 5 hardly makes a difference)
#declare rad_brightness=1; // increase if needed

// ===========================================================
// other control switches:
// ===========================================================
#declare daylight  =1; // 0=off, 1=on : sunlight/sky switch
#declare use_lamps =0; // 0=off, 1=on : lamps switch
#declare use_area  =0; // 0=off, 1=on : soft shadows switch
#declare use_wglass=0; // 0=off, 1=on : window glass switch (turn it on for night scenes)

// ===========================================================
// global settings
// ===========================================================
global_settings {
 max_trace_level 8   // raised a bit from POV-Ray default of 5, to avoid radiosity artefacts
 assumed_gamma 1.0   // warning: needs inverse correction of image_maps!!! (see tutorial for details)
 #if (use_radiosity) // compromise radiosity: somewhat fast but effective and scalable
  radiosity {        // you don't need to touch these settings, just use the radiosity control variables above
   #if (use_radiosity=2) 
    // saving radiosity
    pretrace_start 0.05
    pretrace_end 0.005
    count 160*rad_quality
    nearest_count 10+rad_quality
    error_bound 0.5/rad_quality
    recursion_limit rad_bounces
    brightness rad_brightness
    save_file "saved.rad"
   #else                
    // loading radiosity
    load_file "saved.rad"
    pretrace_start 1
    pretrace_end 1
    count 160*rad_quality
    nearest_count 10+rad_quality
    error_bound 0.5/rad_quality
    recursion_limit rad_bounces
    always_sample off
    brightness rad_brightness
   #end
   gray_threshold .5 
   //randomize on // comment out if you are using MegaPOV: it can help with some artefacts
  }
 #end
}
// default finish for all textures:
#default{texture{finish{ambient 0 diffuse 1 conserve_energy}}}
// standard includes from POV-Ray: we will use predefined items from there
#include "colors.inc"
#include "textures.inc"
#include "glass.inc"

// ===========================================================
// original CA camera, only  changed to use square aspect ratio and to slighty 
// adjust the placement and viewing angle
// ===========================================================
camera {
  location <1433.299316, 85.500000, -1431.583984>
  up <0.0, 1.0, 0.0>
  right <-1.0, 0.0, 0.0>
  look_at <1426.359375, 85.500000, -1531.342896>
  angle 47.822402
}

// ===========================================================
// LightSys: used to obtain light colors and fading, and also to provide a realisitic 
// sunlight and sky
// ===========================================================
// Include CIE color transformation macros by Ive : Lightsys is based on them
#include "CIE.inc" 
// change the CIE white point to typical film temperature
CIE_ColorSystemWhitepoint(CIE_ColSys, Illuminant_D55)
// Main lightsys include 
#declare Lightsys_Scene_Scale=10;
#include "lightsys.inc" 
// Include predefined lumens, spectrums, kelvin temperatures 
#include "lightsys_constants.inc" 
// predefine some useful light colors from emissive spectrums 
#declare Cl_Incandescent=EmissiveSpectrum(ES_Incandescent_60w); 
#declare Cl_Fluorescent =EmissiveSpectrum(ES_Cool_White_Fluor); 
#declare Cl_Halogen =EmissiveSpectrum(ES_Solux_Halog4700K); 
#declare Cl_Daylight =Daylight(6500); 
#declare Cl_Skylight =Daylight(7500); 
// Brightness control (global light multiplier): 
#declare Lightsys_Brightness=1; // adjust for a brighter/dimmer image 
// ===========================================================
// sky sphere and sunlight from Lightsys, replacing the CA exported sunlight and backdrop sphere
#if (daylight)
 #declare North=-z; #declare Az=0; #declare Al=0;
 #declare SolarPosition=< -8660.253906, 14281.480469, -5000.000000 >;
 #declare UseSolarPosition=1;
 #declare Intensity_Mult=4; // brightness of the sky dome and sunlight
 #declare Max_Vertices=1000;
 #declare DomeSize=110000;
 #include "CIE_Skylight"
 #declare Cl_Sunlight =Blackbody(3000+4500*Al/90); 
 light_source{
  SolarPosition
  Light_Color(Cl_Sunlight,SunColor.gray)
  #if (use_area)
  area_light 2000*x,2000*z,8,8 jitter adaptive 1 orient circular
  #end
  fade_power 0
 }
#end
// I didn't  model any exterior surface on CA, 
//so I did put here a plane to bounce some radiosity to the inside
plane{y,-100 pigment{Gray}
#if (use_radiosity<2) no_image no_reflection no_shadow #end // don't show on the second pass
}

// original CA backdrop, with some small changes
#if (use_radiosity<2) // do not use it when calculating radiosity
#declare CHIEFBACKDROP = texture { 
 pigment { uv_mapping image_map { jpeg "Valley.jpg" interpolate 4 once  } }
 finish { 
  #if(daylight)
   ambient 2 // raised a bit for "overexposed" effect
  #else
   ambient 0 // use ambient 1 if you are already using a night backdrop
  #end
  diffuse 0.000000 
  specular 0.000000 reflection 0.000000 
 }
}
mesh {
triangle { <-55869.773438, -38167.843750, -90070.742188> <45933.101563, -38167.843750, -97152.843750> <-55869.773438, 38368.843750, -90070.742188> uv_vectors <0,0> <1,0> <0,1> }
triangle { <45933.101563, -38167.843750, -97152.843750> <-55869.773438, 38368.843750, -90070.742188> <45933.101563, 38368.843750, -97152.843750> uv_vectors <1,0> <0,1> <1,1> }
texture { CHIEFBACKDROP }
no_shadow hollow on
}
#end


// ===========================================================
// artificial light sources, copied from the original CA export, 
// and moved to their own include file:
// ===========================================================
#if (use_lamps)
 // light intensities
 #declare Lm_Floor_Lamp=1; 
 #declare Lm_Eyeball=2;    
 #declare Lm_Recessed=15;  
 #include "tutorial4_lights.inc"
#end

// ===========================================================
// geometry (via Poseray)
// note it automatically includes the _mat.inc file
// ===========================================================
#include "tutorial4_POV_geom.inc"
